CookyChat = LibStub("AceAddon-3.0"):NewAddon("CookyChat","AceConsole-3.0","AceEvent-3.0")
CookyChatHandler = CreateFrame("Frame")
-- |cffFF69B4 pink
-- |cffBF5FFF purple

local icon = LibStub("LibDBIcon-1.0", true)
local ldb = LibStub:GetLibrary("LibDataBroker-1.1")
local cookyToolTip = "|cffBF5FFFCooky|rChat\n|cffFF69B4Left-Click|r: toggle on/off.\n|cffFF69B4Right-Click|r: open settings menu."

local CookyChatLBD = ldb:NewDataObject("CookyChat", {
	label = "CookyChat",
	type = "data source",
	text = "CookyChat",
	icon = "Interface\\AddOns\\CookyChat\\Media\\icon",
})

function CookyChat:OnInitialize()
	CookyChat.db = LibStub("AceDB-3.0"):New("CookyChatDB", CookyChat.defaults, true)
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("CookyChat", self.options)
	self.Groups = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("CookyChat", "|cffBF5FFFCooky|rChat", nil, "groups")
	self.Blacklists = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("CookyChat", "Blacklist", "|cffBF5FFFCooky|rChat", "blacklist")
	
	icon:Register("CookyChat", CookyChatLBD, self.db.profile.icon)
	
	CookyChatHandler:RegisterEvent("CHAT_MSG_BN_WHISPER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_SAY")
	CookyChatHandler:RegisterEvent("CHAT_MSG_GUILD")
	CookyChatHandler:RegisterEvent("CHAT_MSG_OFFICER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_PARTY")
	CookyChatHandler:RegisterEvent("CHAT_MSG_PARTY_LEADER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID_LEADER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID_WARNING")
	CookyChatHandler:RegisterEvent("CHAT_MSG_WHISPER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_YELL")
	
	CookyChat:CreateGroups()
	CookyChat:CreateBlacklist()
	
	if self.db.profile.globalActive then
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon"
	else
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon_bw"
	end
end

function CookyChatLBD:OnEnter()
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint("TOPLEFT", self, "BOTTOMLEFT")
	GameTooltip:ClearLines()
	GameTooltip:AddLine(cookyToolTip, 1, 1, 1, 1)
	GameTooltip:Show()
end

function CookyChatLBD:OnClick(button)
	if button == "LeftButton" then
		print("|cffBF5FFFCooky|rChat: |cffFF69B4"..CookyChat:OnOrOff(true))
		CookyChat:UpdateDisplay()
	elseif button == "RightButton" then
		InterfaceOptionsFrame_OpenToCategory(CookyChat.Groups)
	end
end

function CookyChat:OnOrOff(toggle)
	if toggle then
		self.db.profile.globalActive = not self.db.profile.globalActive
	end

	if self.db.profile.globalActive then 
		return "On."
	else 
		return "Off." 
	end
end

function CookyChat:RefreshMMButton()
	if icon then
		icon:Refresh("CookyChat", self.db.profile.icon)
		if self.db.profile.icon.hide then
			icon:Hide("CookyChat")
		else
			icon:Show("CookyChat")
		end
	end
end

function CookyChat:UpdateDisplay()
	if self.db.profile.globalActive then
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon"
	else
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon_bw"
	end
end

function CookyChat:OnBlacklist(shortSource)
	if self.db.profile.blacklist then
		for i = 1, #self.db.profile.blacklist do
			if string.lower(self.db.profile.blacklist[i]) == string.lower(shortSource) then
				return true
			end
		end
	end
	return false
end

local compareMessage
local trigger
local spamBlock = false
local msgNumber = 0

function CookyChat:FindTrigger(message, event, shortSource, fullSource, pID)
	for i = 1, self.db.profile.numFilled do
		if not self.db.profile.groupCaseSensitive[i] then 
			compareMessage = string.lower(message)
			trigger = string.lower(self.db.profile.trigger[i])
		else
			compareMessage = message
			trigger = self.db.profile.trigger[i]
		end
		
		if string.find(compareMessage, trigger) and self.db.profile.globalActive and self.db.profile.groupActive[i] and not spamBlock then
			C_Timer.After(4, function() msgNumber = 0 spamBlock = false end)
			CookyChat:Reply(event, i, shortSource, fullSource, pID)
			msgNumber = msgNumber + 1
			if msgNumber == 2 then
				spamBlock = true
			end
		end
	end		
end

function CookyChat:Reply(event, num, shortSource, fullSource, pID)
	if event == "CHAT_MSG_SAY" and shortSource ~= UnitName("player") then -- If message is from say and source isn't player
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][1] then -- If seperate channel per group and group is active
			SendChatMessage(self.db.profile.reply[num],"SAY")
		else
			SendChatMessage(self.db.profile.reply[num],"SAY")
		end
	elseif event == "CHAT_MSG_YELL" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][8] then
			SendChatMessage(self.db.profile.reply[num],"YELL")
		else
			SendChatMessage(self.db.profile.reply[num],"YELL")
		end
	elseif event == "CHAT_MSG_GUILD" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][6] then
			SendChatMessage(self.db.profile.reply[num],"GUILD")
		else
			SendChatMessage(self.db.profile.reply[num],"GUILD")
		end
	elseif event == "CHAT_MSG_OFFICER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][7] then
			SendChatMessage(self.db.profile.reply[num],"OFFICER")
		else
			SendChatMessage(self.db.profile.reply[num],"OFFICER")
		end
	elseif event == "CHAT_MSG_PARTY" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][4] then
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		else
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		end	
	elseif event == "CHAT_MSG_PARTY_LEADER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][4] then
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		else
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		end	
	elseif event == "CHAT_MSG_RAID" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][5] then
			SendChatMessage(self.db.profile.reply[num],"RAID")
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end	
	elseif event == "CHAT_MSG_RAID_LEADER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][5] then
			SendChatMessage(self.db.profile.reply[num],"RAID")
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end	
	elseif event == "CHAT_MSG_RAID_WARNING" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][5] then
			SendChatMessage(self.db.profile.reply[num],"RAID")
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end
	elseif event == "CHAT_MSG_WHISPER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][2] then
			SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
		else
			SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
		end
	elseif event == "CHAT_MSG_BN_WHISPER" then
		if not BNIsSelf(pID) then
			if self.db.profile.seperateChannelActivityOption and self.db.profile.groupChannelActive[num][3] then
				BNSendWhisper(pID,self.db.profile.reply[num])
			else
				BNSendWhisper(pID,self.db.profile.reply[num])
			end
		end
	end
end

CookyChatHandler:SetScript("OnEvent", function(_,event,message,fullSource,_,_,shortSource,_,_,_,_,_,_,_,pID)
	if not CookyChat:OnBlacklist(shortSource) then
		CookyChat:FindTrigger(message, event, shortSource, fullSource, pID)
	end
end)