local MAX_GROUPS = 30
local MAX_BLACKLIST = 10

local channelDefault = {
	true, -- SAY
	true, -- WHISPER
	true, -- BN WHISPER
	true, -- PARTY 
	true, -- RAID
	true, -- GUILD
	true, -- OFFICER
	true, -- YELL
}
CookyChat.defaults = {	
	profile = {
		trigger = {
		},
		reply = {
		},
		groupActive = {
		},
		groupCaseSensitive = {
		},
		groupChannelActive = {
		},
		blacklist = {
		},
		
		hideChannels = true,
		globalActive = true,
		globalChannelActive = true,
		caseSensitive = false,
		numFilled = 0,
		numBlackList = 0,
		seperateChannelActivityOption = false,
		icon = {hide = false, radius = 80, minimapPos = 45},
	},
}

local tempTrigger
local tempReply

function CookyChat:CreateNewGroup()
	if tempTrigger == "" or tempTrigger == nil then
		print("|cffBF5FFFCooky|rChat: Missing trigger.")
	end
	if tempReply == "" or tempReply == nil then
		print("|cffBF5FFFCooky|rChat: Missing reply.")
	end
	if CookyChat.db.profile.numFilled == MAX_GROUPS then
		print("|cffBF5FFFCooky|rChat: Maximum number of groups filled.")
	end
	
	if tempTrigger and tempReply and (CookyChat.db.profile.numFilled < MAX_GROUPS) then
		
		table.insert(CookyChat.db.profile.trigger, tempTrigger)
		table.insert(CookyChat.db.profile.reply, tempReply)
		table.insert(CookyChat.db.profile.groupActive, true)
		table.insert(CookyChat.db.profile.groupCaseSensitive, false)
		table.insert(CookyChat.db.profile.groupChannelActive, channelDefault)
		CookyChat.db.profile.numFilled = CookyChat.db.profile.numFilled + 1
		tempTrigger = nil
		tempReply = nil
		print("|cffBF5FFFCooky|rChat: New group created.")
	end
end

function CookyChat:DeleteGroup(group)
	table.remove(CookyChat.db.profile.trigger, group)
	table.remove(CookyChat.db.profile.reply, group)
	table.remove(CookyChat.db.profile.groupActive, group)
	table.remove(CookyChat.db.profile.groupCaseSensitive, group)
	table.remove(CookyChat.db.profile.groupChannelActive, group)
	CookyChat.db.profile.numFilled = CookyChat.db.profile.numFilled - 1
	print("|cffBF5FFFCooky|rChat: Group deleted.")
end

function CookyChat:CreateNewBlacklist()
	if tempBlacklist == "" or tempBlacklist == nil then
		print("|cffBF5FFFCooky|rChat: Missing name.")
	end
	if CookyChat.db.profile.numBlackList == MAX_BLACKLIST then
		print("|cffBF5FFFCooky|rChat: Blacklist limit reached.")
	end
	
	if tempBlacklist and (CookyChat.db.profile.numBlackList < MAX_BLACKLIST) then
		table.insert(CookyChat.db.profile.blacklist, tempBlacklist)
		print("|cffBF5FFFCooky|rChat: "..tempBlacklist.." added to blacklist.")
		tempBlacklist = nil
		CookyChat.db.profile.numBlackList = CookyChat.db.profile.numBlackList + 1
	end
end

function CookyChat:DeleteBlackList(group)
	table.remove(CookyChat.db.profile.blacklist, group)
	print("|cffBF5FFFCooky|rChat: Blacklist deleted.")
	CookyChat.db.profile.numBlackList = CookyChat.db.profile.numBlackList - 1
end

CookyChat.options = {
	name = "CookyChat",
	handler = CookyChat,
	type = "group",
	args = {
	
		groups = {
			name = "Group Settings",
			type = "group",
			order = 1,
			args = {
				minimapIcon = {
					type = "toggle",
					name = "Minimap Icon",
					desc = "Turns the minimap icon on or off.",
					get = function() return not CookyChat.db.profile.icon.hide end,
					set = function() 
							CookyChat.db.profile.icon.hide = not CookyChat.db.profile.icon.hide 
							CookyChat:RefreshMMButton()
							end,
					order = 1,
				},
				
				seperateChannelActive = {
					type = "toggle",
					name = "Per Channel Activity",
					desc = "Allows trigger groups to work on a per channel basis.",
					get = function() return CookyChat.db.profile.seperateChannelActivityOption end,
					set = function(info,val) CookyChat.db.profile.seperateChannelActivityOption = not CookyChat.db.profile.seperateChannelActivityOption end,
					order = 2,
				},
				
				hidePerChannel = {
					type = "toggle",
					desc = "Hide/Show the 'Active Channels' selection. The trigger will still reply on only the selected channels, this merely hides the selection of checkboxes",
					name = "Show the Active Channels",
					order = 3,
					hidden = function() return not CookyChat.db.profile.seperateChannelActivityOption end,
					get = function() return not CookyChat.db.profile.hideChannels end,
					set = function(info, val) CookyChat.db.profile.hideChannels = not CookyChat.db.profile.hideChannels end,
				},
			
				newGroup = {
					type = "group",
					name = "Create new groups",
					inline = true,
					order = 4,
					args = {
						newTrigger = {
							type = "input",
							name = "New group's trigger",
							desc = "The message that will trigger the autoreply.",
							order = 1,
							set = function(info,val) tempTrigger = val end,
							get = function() return tempTrigger end,
						},

						newReply = {
							type = "input",
							name = "New group's reply",
							desc = "The message that will be sent.",
							order = 2,
							set = function(info,val) tempReply = val end,
							get = function() return tempReply end,
						},
						
						applyButton = {
							type = "execute",
							name = "Create your new group",
							-- width = "full",
							order = 3,
							func = function() CookyChat:CreateNewGroup() end,
						},
					},
				},
			},
		},
		
		blacklist = {
			name = "Blacklist",
			type = "group",
			order = 3,
			args = {
				newBlacklist = {
					type = "group",
					name = "Add a characters name to the blacklist",
					inline = true,
					order = 1,
					args = {
						blacklistName = {
							type = "input",
							name = "Name",
							order = 1,
							set = function(info,val) tempBlacklist = val end,
							get = function() return tempBlacklist end,
						},
						
						applyButton = {
							type = "execute",
							name = "Add name to blacklist",
							order = 2,
							func = function() CookyChat:CreateNewBlacklist() end,
						},
					},
				},
			
			},
		},
	},
}

function CookyChat:CreateGroups()
	for i = 1, MAX_GROUPS do
		local group = {
			type = "group",
			inline = true,
			order = 4+i,
			hidden = function() return not (i <= CookyChat.db.profile.numFilled) end,
			name = "Trigger Group "..i,
			args = {
				trigger = {
					type = "input",
					name = "Trigger",
					get = function() return CookyChat.db.profile.trigger[i] end,
					set = function(info, val) CookyChat.db.profile.trigger[i] = val end,
					order = 1,
				},
				
				reply = {
					type = "input",
					name = "Reply",
					get = function() return CookyChat.db.profile.reply[i] end,
					set = function(info, val) CookyChat.db.profile.reply[i] = val end,
					order = 2,
				},
				
				delete = {
					type = "execute",
					name = "Delete this group",
					-- width = "full",
					func = function() CookyChat:DeleteGroup(i) end,
					order = 3,
				},
				
				active = {
					type = "toggle",
					name = "Active",
					desc = "Turns this group on or off.",
					get = function() return CookyChat.db.profile.groupActive[i] end,
					set = function(info, val) CookyChat.db.profile.groupActive[i] = val end,
					order = 4,
				},
				
				caseSensitive = {
					type = "toggle",
					name = "Case Sensitive",
					desc = "Turns case sensitivity on or off for this group",
					get = function() return CookyChat.db.profile.groupCaseSensitive[i] end,
					set = function() CookyChat.db.profile.groupCaseSensitive[i] = not CookyChat.db.profile.groupCaseSensitive[i] end,
					order = 5,
				},
				
				channelSelectGroup = {
					type = "group",
					name = "Active Channels",
					inline = true,
					desc = "Choose which chat channels the group is active on.",
					hidden = function() 
								if not CookyChat.db.profile.seperateChannelActivityOption or CookyChat.db.profile.hideChannels then
									return true
								end
							end,
					order = 6,
					args = {
						channelSelectGroupSay = {
							type = "toggle",
							name = "Say",
							order = 1,
							get = function() return CookyChat.db.profile.groupChannelActive[i][1] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][1] = not CookyChat.db.profile.groupChannelActive[i][1] end,
						},
						channelSelectGroupWhisper = {
							type = "toggle",
							name = "Whispers",
							order = 2,
							get = function() return CookyChat.db.profile.groupChannelActive[i][2] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][2] = not CookyChat.db.profile.groupChannelActive[i][2] end,
						},
						channelSelectGroupBNWhisper = {
							type = "toggle",
							name = "Battle.Net whispers",
							order = 3,
							get = function() return CookyChat.db.profile.groupChannelActive[i][3] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][3] = not CookyChat.db.profile.groupChannelActive[i][3] end,
						},
						channelSelectGroupParty = {
							type = "toggle",
							name = "Party",
							order = 4,
							get = function() return CookyChat.db.profile.groupChannelActive[i][4] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][4] = not CookyChat.db.profile.groupChannelActive[i][4] end,
						},
						channelSelectGroupRaid = {
							type = "toggle",
							name = "Raid",
							order = 5,
							get = function() return CookyChat.db.profile.groupChannelActive[i][5] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][5] = not CookyChat.db.profile.groupChannelActive[i][5] end,
						},
						channelSelectGroupGuild = {
							type = "toggle",
							name = "Guild",
							order = 6,
							get = function() return CookyChat.db.profile.groupChannelActive[i][6] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][6] = not CookyChat.db.profile.groupChannelActive[i][6] end,
						},
						channelSelectGroupOfficer = {
							type = "toggle",
							name = "Officer",
							order = 7,
							get = function() return CookyChat.db.profile.groupChannelActive[i][7] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][7] = not CookyChat.db.profile.groupChannelActive[i][7] end,
						},
						channelSelectGroupYell = {
							type = "toggle",
							name = "Yell",
							order = 7,
							get = function() return CookyChat.db.profile.groupChannelActive[i][8] end,
							set = function(info,val) CookyChat.db.profile.groupChannelActive[i][8] = not CookyChat.db.profile.groupChannelActive[i][8] end,
						},
					},
				},
			},
		}
		
		CookyChat.options.args.groups.args[tostring(i)] = group
	end
end

function CookyChat:CreateBlacklist()
	for i = 1, MAX_BLACKLIST do
		local BLgroup = {
			type = "group",
			inline = true,
			order = 2,
			name = "Blacklist "..i,
			hidden = function() return not (i <= CookyChat.db.profile.numBlackList) end,
			args = {
				blacklist = {
					type = "input",
					name = "Name",
					get = function() return CookyChat.db.profile.blacklist[i] end,
					set = function(info, val) CookyChat.db.profile.blacklist[i] = val end,
					order = 1,
				},
				delete = {
					type = "execute",
					name = "Delete from blacklist",
					func = function() CookyChat:DeleteBlackList(i) end,
					order = 3,
				},
			},
		}
		
		CookyChat.options.args.blacklist.args[tostring(i)] = BLgroup
	end
end